<?php
/* Copyright 2011 Ryan Nutt - Aelora Web Services LLC
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public Licese, version 2, as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation,Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */

/*
Plugin Name: Auto Future Date
Plugin URI: http://reliti.com/tag/auto-future-date/
Description: Automatically schedule posts in the future
Author: Ryan Nutt
Version: 0.1
Author URI: http://reliti.com
*/

register_activation_hook(__FILE__,'afd_activate');
register_deactivation_hook(__FILE__,'afd_deactivate');

function afd_activate() {
    add_option('afd_options',
        array(
            'minDays' => 1,
            'maxDays' => 5,
            'startTime' => '8:00',
            'endTime' => '17:00'
        ));
}
function afd_deactivate() {
    delete_option('afd_options'); 
}

if (is_admin()) {
    add_action('admin_print_scripts-post-new.php', 'afd_admin_scripts');
    add_action('admin_print_scripts-post.php', 'afd_admin_scripts');
    wp_register_script('afd-js', plugins_url('/autoFutureDate.js', __FILE__));
    add_action('wp_ajax_afd_get_date', 'afd_ajax');

    // Option pages
    add_action('admin_menu', 'afd_create_menu');
    add_filter('pre_update_option_afd_options', 'afd_update_options');

    function afd_admin_scripts() {
        wp_enqueue_script('jquery');
        wp_enqueue_script('afd-js');
    }

    function afd_ajax() {
        $dateNow = date('U');
        $opts = get_option('afd_options');

        $lastPost = get_posts(array(
            'numberposts' => 1,
            'orderby' => 'post_date',
            'order' => 'DESC',
            'post_type' => 'post',
            'post_status' => 'publish,future'
        ));

        $now = date('U');

        if (count($lastPost) < 1) {
            $lastTimestamp = $now;
        }
        else {
            $lastTimestamp = date('U', strtotime($lastPost[0]->post_date));
            if ($lastTimestamp < $now)
                $lastTimestamp = $now;
        }

        $numDays = rand($opts['minDays'], $opts['maxDays']);
        $date = $lastTimestamp + ($numDays * 24 * 60 * 60);

        $time = date('H:i:s', afd_random_time($opts['startTime'], $opts['endTime']))."\n";

        $newDate = date('D M j Y', $date).' '.$time;
        echo $newDate;

        die();
    }

    function afd_random_time($start, $end) {
        $start = strtotime($start);
        $end = strtotime($end);

        $ts = rand($start, $end);
        return $ts; 
    }

    function afd_create_menu() {
        add_options_page('Auto Future Date Options', 'Auto Future Date', 'manage_options', 'afd-options', 'afd_options_page');
    }
    function afd_options_page() {
        $opts = get_option('afd_options'); 
        ?>
        <div class="wrap">
            <h2>Auto Future Date Settings
                <a target="_blank" href="http://reliti.com/tag/auto-future-date/?utm_source=wp&utm_medium=link&utm_campaign=afd">
            <img src="<?php echo plugins_url('help.png', __FILE__); ?>" />
                </a>
            </h2>
        <form method="post" action="options.php">
        <?php wp_nonce_field('update-options'); ?>
        <table class="form-table">
            <tr>
                <th scope="row">Start Time</th>
                <td><input type="text" name="afd_options[startTime]" value="<?php echo $opts['startTime'];?>" /></td>
            </tr>
            <tr>
                <th scope="row">End Time</th>
                <td><input type="text" name="afd_options[endTime]" value="<?php echo $opts['endTime']; ?>" /></td>
            </tr>
            <tr>
                <th scope="row">Min Days</th>
                <td><input type="text" name="afd_options[minDays]" value="<?php echo $opts['minDays']; ?>" /></td>
            </tr>
            <tr>
                <th scope="row">Max Days</th>
                <td><input type="text" name="afd_options[maxDays]" value="<?php echo $opts['maxDays']; ?>" /></td>
            </tr>
        </table>
        <input type="hidden" name="action" value="update" />
        <input type="hidden" name="page_options" value="afd_options" />

        <p class="submit">
            <input type="submit" class="button-primary" value="<?php _e('Save Changes'); ?>" />
        </p>
        </form>
            
            </div>
<?php
    }

    function afd_update_options($args) {
        $newSettings = array(
            'startTime' => '8:00',
            'endTime' => '17:00',
            'minDays' => (int)$args['minDays'],
            'maxDays' => (int)$args['maxDays']
        );

        // Validate the time entries to make sure they're formatted correctly
        $start = strtotime($args['startTime']);
        if ($start != 0) {
            $newSettings['startTime'] = date('G:i', $start);
        }
        $end = strtotime($args['endTime']);
        if ($end != 0) {
            $newSettings['endTime'] = date('G:i', $end);
        }

        return $newSettings; 
    }
}


?>